<?php
header( 'content-type: text/html; charset=utf-8' );

class WebPage
{
    /**
     * @var string Texte compris entre <head> et </head>
     */
    private $head  = null ;
    /**
     * @var string Texte compris entre <title> et </title>
     */
    private $title = null ;
	
	/**
     * @var string Texte compris entre <div> et </div class="app-bar"> du bandeau du haut
     */
    private $header  = null ;
	
    /**
     * @var string Texte compris entre <body> et </body>
     */
    private $body  = null ;

    /**
     * Constructeur
     * @param string $title Titre de la page
     */
    public function __construct($title=null)
    {
      $this->setTitle($title);
    }

    /**
     * Protéger les caractères spéciaux pouvant dégrader la page Web
     * @param string $string La chaîne à protéger
     * @return string La chaîne protégée
     */
    public function escapeString($string)
    {
      return htmlentities($string, ENT_QUOTES|ENT_HTML5, "utf-8") ;
    }

    /**
     * Affecter le titre de la page
     * @param string $title Le titre
     */
    public function setTitle($title)
    {
		$this->title = $title;
    }

    /**
     * Ajouter un contenu dans head (a moi de faire l'indentation à l'appel de cette fonction)
     * @param string $content Le contenu à ajouter
     * @return void
     */
    public function appendToHead($content)
    {
      $this->head .= $content;
    }

    /**
     * Ajouter un contenu CSS dans head
     * @param string $css Le contenu CSS à ajouter
     * @return void
     */
    public function appendCss($css)
    {
      $this->appendToHead(<<<CONTENT
	  
		<style>
{$css}
		</style>

CONTENT
);
    }

    /**
     * Ajouter l'URL d'un script CSS dans head
     * @param string $url L'URL du script CSS
     * @return void
     */
    public function appendCssUrl($url)
    {
      $this->appendToHead("\n		<link rel='stylesheet'  type='text/css' href='".$url."'>");
    }

    /**
     * Ajouter un contenu JavaScript dans head
     * @param string $js Le contenu JavaScript à ajouter
     * @return void
     */
    public function appendJs($js)
    {
      $this->appendToHead(<<<CONTENT

		<script>
			{$js}
		</script>
CONTENT
);
    }

    /**
     * Ajouter l'URL d'un script JavaScript dans head
     * @param string $url L'URL du script JavaScript
     * @return void
     */
    public function appendJsUrl($url)
    {
      $this->appendToHead("\n		<script src=".$url."></script>");
    }

    /**
     * Ajouter un contenu dans body (a moi de faire l'indentation à l'appel de cette fonction)
     * @param string $content Le contenu à ajouter
     * @return void
     */
    public function appendContent($content)
    {
	  $this->body .= $content;
    }
	
	/**
     * Ajouter un contenu dans body (a moi de faire l'indentation à l'appel de cette fonction)
     * @param string $content Le contenu à ajouter
     * @return void
     */
    public function appendHeader($content)
    {
	  $this->header .= $content;
    }
	

    /**
     * Produire la page Web complète
     * @return string
     */
    public function toHTML()
    {
      if (is_null($this->title))
      {
		throw new Exception(__CLASS__ . ": Le titre est manquant") ;
      }
	  $time=strftime("Dernière modification de cette page le %d/%m/%Y à %Hh%M", getlastmod());
      $html=<<<HTML
<!DOCTYPE html>
<html>
	<head>
		<meta charset="utf-8"/>
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
		<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
        <meta name="viewport" content="width=device-width">
        <meta name="description" content="filter &amp; sort magical layouts">
        <link rel="stylesheet" href="isotope-docs.css" media="screen">
        <link href="Metro-UI-CSS-master/build/css/metro.css" rel="stylesheet">
        <link href="style.css" rel="stylesheet">
        <script src="Metro-UI-CSS-master/test/RequireJS/scripts/jquery.js"></script>
        <script src="Metro-UI-CSS-master/build/js/metro.js"></script>
        <script src="jquery.min.js"></script>
        <script src="isotope-docs.min.js"></script>
HTML;
      if($this->head == null)
	  {
		$html.=<<<HTML

		<title>{$this->title}</title>
	</head>
HTML;
	  }
	  else
	  {
		$html.=<<<HTML

		<title>{$this->title}</title>
{$this->head}
	</head>
HTML;
	  }
      $html.=<<<HTML

	<body>
        <div class="app-bar">
            <a class="app-bar-element" href="index.php">VocaHelper</a>
            <span class="app-bar-divider"></span>
			<a class="app-bar-element" href="ConcoursMicrosoftAzure.pdf">Descriptif du projet</a>
            <span class="app-bar-divider"></span>
			{$this->header}
		</div>
{$this->body}
	<footer>
		<br/>
		<span id='temps'>
			{$time}
		</span>
	</footer>
  </body>
</html>
HTML;
	return $html;
    }
}